==> ejc-jltest-impl-3.0.0-20240323.031742-97-sources.jar: com/ejianc/business/jltest/newtest/bean/TargetbEntity.java <==
package com.ejianc.business.jltest.newtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.jltest.newtest.bean.TargetbDetailEntity;
/**
 * 目标考核
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_targetb")
public class TargetbEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 目标考核号
    @TableField(value="target_name")
    private String targetName; // 目标考核名称
    @TableField(value="target_date")
    private Date targetDate; // 考核时间
    @TableField(value="safeteama_id")
    private Long safeteamaId; // 安全小组主键
    @TableField(value="safeteama_name")
    private String safeteamaName; // 安全小组发文名称
    @TableField(value="safeteama_bill_code")
    private String safeteamaBillCode; // 安全小组成立发文字号
    @TableField(value="safeteama_date")
    private Date safeteamaDate; // 安全小组发文日期
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="planc_flag")
    private Integer plancFlag; // 计划引用状态 1-未引用 2-引用

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="targetbDetailService")
    private List<TargetbDetailEntity> targetbDetailList = new ArrayList<>(); // 目标考核详情
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getTargetName() {
        return targetName;
    }

    public void setTargetName(String targetName) {
        this.targetName = targetName;
    }
    public Date getTargetDate() {
        return targetDate;
    }

    public void setTargetDate(Date targetDate) {
        this.targetDate = targetDate;
    }
    public Long getSafeteamaId() {
        return safeteamaId;
    }

    public void setSafeteamaId(Long safeteamaId) {
        this.safeteamaId = safeteamaId;
    }
    public String getSafeteamaName() {
        return safeteamaName;
    }

    public void setSafeteamaName(String safeteamaName) {
        this.safeteamaName = safeteamaName;
    }
    public String getSafeteamaBillCode() {
        return safeteamaBillCode;
    }

    public void setSafeteamaBillCode(String safeteamaBillCode) {
        this.safeteamaBillCode = safeteamaBillCode;
    }
    public Date getSafeteamaDate() {
        return safeteamaDate;
    }

    public void setSafeteamaDate(Date safeteamaDate) {
        this.safeteamaDate = safeteamaDate;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getPlancFlag() {
        return plancFlag;
    }

    public void setPlancFlag(Integer plancFlag) {
        this.plancFlag = plancFlag;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    

    public List<TargetbDetailEntity> getTargetbDetailList() {
        return targetbDetailList;
    }

    public void setTargetbDetailList(List<TargetbDetailEntity> targetbDetailList) {
        this.targetbDetailList = targetbDetailList;
    }
}

==> ejc-jltest-impl-3.0.0-20240328.061301-132-sources.jar: com/ejianc/business/jltest/newtest/bean/TargetbEntity.java <==
package com.ejianc.business.jltest.newtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.jltest.newtest.bean.TargetbDetailEntity;
/**
 * 目标考核
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_targetb")
public class TargetbEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 目标考核
    @TableField(value="targetb_name")
    private String targetbName; // 考核名称
    @TableField(value="targetb_date")
    private Date targetbDate; // 考核年度
    @TableField(value="targetb_unit")
    private String targetbUnit; // 考核单位
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="memo")
    private String memo; // 考核说明
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="targetbDetailService",pidName="targetbId")
    private List<TargetbDetailEntity> targetbDetailList = new ArrayList<>(); // 目标考核详情
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getTargetbName() {
        return targetbName;
    }

    public void setTargetbName(String targetbName) {
        this.targetbName = targetbName;
    }
    public Date getTargetbDate() {
        return targetbDate;
    }

    public void setTargetbDate(Date targetbDate) {
        this.targetbDate = targetbDate;
    }
    public String getTargetbUnit() {
        return targetbUnit;
    }

    public void setTargetbUnit(String targetbUnit) {
        this.targetbUnit = targetbUnit;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    

    public List<TargetbDetailEntity> getTargetbDetailList() {
        return targetbDetailList;
    }

    public void setTargetbDetailList(List<TargetbDetailEntity> targetbDetailList) {
        this.targetbDetailList = targetbDetailList;
    }
}
